==> 1.0.2.tar.gz: lib/api/usage_api.dart <==
part of forestvpn_api.api;



class UsageApi {
  final ApiClient apiClient;

  UsageApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Get traffic usage for current month
  ///
  /// 
  Future<UsageTraffic> getTraffic() async {
    Object postBody = null;

    // verify required params are set

    // create path and map variables
    String path = "/usage/traffic/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    
    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'UsageTraffic') as UsageTraffic ;
    } else {
      return null;
    }
  }
  /// Usage traffic update
  ///
  /// 
  Future trafficUpdate({ List<UsageTrafficUpdateRequest> request }) async {
    Object postBody = request;

    // verify required params are set

    // create path and map variables
    String path = "/usage/traffic/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    
    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          ;
    } else {
      return ;
    }
  }
}

==> 1.0.3.tar.gz: lib/api/usage_api.dart <==
part of forestvpn_api.api;



class UsageApi {
  final ApiClient apiClient;

  UsageApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Get traffic usage for current month with HTTP info returned
  ///
  /// 
  Future<Response> getTrafficWithHttpInfo() async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    String path = "/usage/traffic/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get traffic usage for current month
  ///
  /// 
  Future<UsageTraffic> getTraffic() async {
    Response response = await getTrafficWithHttpInfo();
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'UsageTraffic') as UsageTraffic;
    } else {
      return null;
    }
  }

  /// Usage traffic update with HTTP info returned
  ///
  /// 
  Future trafficUpdateWithHttpInfo({ List<UsageTrafficUpdateRequest> request }) async {
    Object postBody = request;

    // verify required params are set

    // create path and map variables
    String path = "/usage/traffic/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Usage traffic update
  ///
  /// 
  Future trafficUpdate({ List<UsageTrafficUpdateRequest> request }) async {
    Response response = await trafficUpdateWithHttpInfo( request: request );
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

}
